@@ -11,7 +11,7 @@ use File::Spec;
 use Log::Any 0.11;
 use Log::Any::Adapter;
 
-our $VERSION = 0.42; # xVERSION
+our $VERSION = 0.43; # xVERSION
 
 our $ALT = "FWR";
 
@@ -19,6 +19,7 @@ use vars qw($dbg_ctx);
 
 my %PATTERN_STYLES = (
     plain             => '%m',
+    plain_nl          => '%m%n',
     script_short      => '[%r] %m%n',
     script_long       => '[%d] %m%n',
     daemon            => '[pid %P] [%d] %m%n',
@@ -609,7 +610,8 @@ sub _default_screen {
                                    $ENV{LOG_CATEGORY_LEVEL},
                                    $spec->{category_level}),
         category => '',
-        pattern_style => _set_pattern_style('script_short'),
+        pattern_style => _set_pattern_style(
+            $ENV{LOG_ELAPSED_TIME_IN_SCREEN} ? 'script_short' : 'plain_nl'),
         pattern => undef,
     };
 }
@@ -898,7 +900,7 @@ Log::Any::App - An easy way to use Log::Any in applications
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -1565,10 +1567,17 @@ C<pattern_style> instead of directly specifying C<pattern>. example:
 
                 Equivalent to pattern: '%m'
 
+ plain_nl       Message plus newline. The default  Message
+                for screen without
+                LOG_ELAPSED_TIME_IN_SCREEN.
+
+                Equivalent to pattern: '%m%n'
+
  script_short   For scripts that run for a short   [234] Message
                 time (a few seconds). Shows just
                 the number of milliseconds. This
-                is the default for screen.
+                is the default for screen under
+                LOG_ELAPSED_TIME_IN_SCREEN.
 
                 Equivalent to pattern:
                 '[%r] %m%n'
@@ -1654,6 +1663,10 @@ Turn on Log::Any::App's debugging:
 
  LOGANYAPP_DEBUG (bool)
 
+Turn on showing elapsed time in screen:
+
+ LOG_ELAPSED_TIME_IN_SCREEN (bool)
+
 =head1 FAQ
 
 =head2 Why?
@@ -1797,7 +1810,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
